netapp_ontap.models.analytics_histogram_by_time API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.analytics_histogram_by_time`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AnalyticsHistogramByTimeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AnalyticsHistogramByTime object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aged_data_metric: float GET POST PATCH`

    A score summarizing how old the data is. A higher value means the data is older.

    Example: 15.23

  `labels: List[str] GET POST PATCH`

    The labels field of the analytics_histogram_by_time.

  `newest_label: str GET POST PATCH`

    The newest time label with a non-zero histogram value.

  `oldest_label: str GET POST PATCH`

    The oldest time label with a non-zero histogram value.

  `percentages: List[float] GET POST PATCH`

    Percentages for this histogram

    Example: [0.1,11.24,0.18,15.75,0.75,83.5,0]

  `values: List[Size] GET POST PATCH`

    Values for this histogram

    Example: [15925248,1735569408,27672576,2430595072,116105216,12889948160,0]